/* slovnikar 1.03 */

#include <gamalib/language.h>

namespace GaMaLib {

const char* T_language_cpp_internal_error = " internal error : program must call function set_gama_language() ";

const char* T_GKF_bad_angle = T_language_cpp_internal_error;
const char* T_GKF_bad_attribute_angle_dev = T_language_cpp_internal_error;
const char* T_GKF_bad_attribute_direction_dev = T_language_cpp_internal_error;
const char* T_GKF_bad_attribute_distance_dev = T_language_cpp_internal_error;
const char* T_GKF_bad_coordinate_x = T_language_cpp_internal_error;
const char* T_GKF_bad_coordinate_y = T_language_cpp_internal_error;
const char* T_GKF_bad_direction = T_language_cpp_internal_error;
const char* T_GKF_bad_distance = T_language_cpp_internal_error;
const char* T_GKF_bad_height = T_language_cpp_internal_error;
const char* T_GKF_bad_height_diff = T_language_cpp_internal_error;
const char* T_GKF_bad_instrument_reflector_height = T_language_cpp_internal_error;
const char* T_GKF_bad_network_configuration_unknown_parameter = T_language_cpp_internal_error;
const char* T_GKF_bad_orientation_angle = T_language_cpp_internal_error;
const char* T_GKF_bad_vector_data = T_language_cpp_internal_error;
const char* T_GKF_bad_zangle = T_language_cpp_internal_error;
const char* T_GKF_coordinate_x_is_not_defined = T_language_cpp_internal_error;
const char* T_GKF_coordinate_y_is_not_defined = T_language_cpp_internal_error;
const char* T_GKF_coordinates_without_covariance_matrix = T_language_cpp_internal_error;
const char* T_GKF_cov_dim_differs_from_number_of_coordinates = T_language_cpp_internal_error;
const char* T_GKF_cov_dim_differs_from_number_of_vectors = T_language_cpp_internal_error;
const char* T_GKF_cov_mat_bad_band_width = T_language_cpp_internal_error;
const char* T_GKF_cov_mat_bad_dim = T_language_cpp_internal_error;
const char* T_GKF_cov_mat_bad_dim_not_enough_elements = T_language_cpp_internal_error;
const char* T_GKF_cov_mat_bad_dim_too_many_elements = T_language_cpp_internal_error;
const char* T_GKF_cov_mat_bad_element = T_language_cpp_internal_error;
const char* T_GKF_cov_mat_missing_band_width = T_language_cpp_internal_error;
const char* T_GKF_cov_mat_missing_dim = T_language_cpp_internal_error;
const char* T_GKF_covariance_matrix_is_not_positive_definite = T_language_cpp_internal_error;
const char* T_GKF_e01a_illegal_tag = T_language_cpp_internal_error;
const char* T_GKF_e01b_after_tag = T_language_cpp_internal_error;
const char* T_GKF_error_on_reading_of_absolute_terms_tolerance = T_language_cpp_internal_error;
const char* T_GKF_error_on_reading_of_confidence_probability = T_language_cpp_internal_error;
const char* T_GKF_error_on_reading_of_standard_deviation = T_language_cpp_internal_error;
const char* T_GKF_illegal_standard_deviation = T_language_cpp_internal_error;
const char* T_GKF_illegal_text = T_language_cpp_internal_error;
const char* T_GKF_illegal_value_of_gama_xml_version = T_language_cpp_internal_error;
const char* T_GKF_missing_forepoint_id = T_language_cpp_internal_error;
const char* T_GKF_missing_from_ID = T_language_cpp_internal_error;
const char* T_GKF_missing_left_forepoint_id = T_language_cpp_internal_error;
const char* T_GKF_missing_observed_value = T_language_cpp_internal_error;
const char* T_GKF_missing_point_ID = T_language_cpp_internal_error;
const char* T_GKF_missing_right_forepoint_id = T_language_cpp_internal_error;
const char* T_GKF_missing_standpoint_id = T_language_cpp_internal_error;
const char* T_GKF_missing_tag_network = T_language_cpp_internal_error;
const char* T_GKF_missing_to_ID = T_language_cpp_internal_error;
const char* T_GKF_multiple_definition_of_xy_in_tag_point = T_language_cpp_internal_error;
const char* T_GKF_multiple_definition_of_z_in_tag_point = T_language_cpp_internal_error;
const char* T_GKF_must_start_with_gama_xml = T_language_cpp_internal_error;
const char* T_GKF_no_observations_after_cov_mat = T_language_cpp_internal_error;
const char* T_GKF_point_must_define_xy_andor_z_inside_tag_coordinates = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_angle = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_coordinates = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_cov_mat = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_direction = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_distance = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_gama_xml = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_height_differences = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_obs = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_points = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_points_observations = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_slopedist = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_vectors = T_language_cpp_internal_error;
const char* T_GKF_undefined_attribute_of_zangle = T_language_cpp_internal_error;
const char* T_GKF_undefined_height_type = T_language_cpp_internal_error;
const char* T_GKF_undefined_point_type = T_language_cpp_internal_error;
const char* T_GKF_undefined_value_of_attribute = T_language_cpp_internal_error;
const char* T_GKF_vectors_without_covariance_matrix = T_language_cpp_internal_error;
const char* T_GKF_wrong_type_of_standard_deviation = T_language_cpp_internal_error;
const char* T_GaMa_Adjustment_of_geodetic_network = T_language_cpp_internal_error;
const char* T_GaMa_Approximate_coordinates_replaced = T_language_cpp_internal_error;
const char* T_GaMa_During_statistical_analysis_we_work = T_language_cpp_internal_error;
const char* T_GaMa_Free_network = T_language_cpp_internal_error;
const char* T_GaMa_Free_network_defect_is = T_language_cpp_internal_error;
const char* T_GaMa_General_solution_parameters = T_language_cpp_internal_error;
const char* T_GaMa_Given_network_configuration_can_not_be_adjusted = T_language_cpp_internal_error;
const char* T_GaMa_Maximal_decrease_of_m0 = T_language_cpp_internal_error;
const char* T_GaMa_Maximal_normalized_residual = T_language_cpp_internal_error;
const char* T_GaMa_No_network_points_defined = T_language_cpp_internal_error;
const char* T_GaMa_No_observations_available = T_language_cpp_internal_error;
const char* T_GaMa_No_points_available = T_language_cpp_internal_error;
const char* T_GaMa_No_unknowns_defined = T_language_cpp_internal_error;
const char* T_GaMa_Observatios_with_outlying_absolute_terms_removed = T_language_cpp_internal_error;
const char* T_GaMa_Ratio_empirical_to_apriori = T_language_cpp_internal_error;
const char* T_GaMa_Review_of_fixed_points = T_language_cpp_internal_error;
const char* T_GaMa_abstrm_Review_of_outlying_abs_terms = T_language_cpp_internal_error;
const char* T_GaMa_abstrm_header1 = T_language_cpp_internal_error;
const char* T_GaMa_abstrm_header2 = T_language_cpp_internal_error;
const char* T_GaMa_adjobs_Adjusted_observations = T_language_cpp_internal_error;
const char* T_GaMa_adjobs_adjusted = T_language_cpp_internal_error;
const char* T_GaMa_adjobs_header1 = T_language_cpp_internal_error;
const char* T_GaMa_adjobs_observed = T_language_cpp_internal_error;
const char* T_GaMa_adjobs_value = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_Review_of_unknowns_bearings = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_Review_of_unknowns_coordidantes = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_Review_of_unknowns_heights = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_constrained = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_header1 = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_header2 = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_header3 = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_header4 = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_header5 = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_header6 = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_mean_position_error_average = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_mean_position_error_maximal = T_language_cpp_internal_error;
const char* T_GaMa_adjunk_mean_position_error_on_point = T_language_cpp_internal_error;
const char* T_GaMa_adjustment_iteration = T_language_cpp_internal_error;
const char* T_GaMa_angle = T_language_cpp_internal_error;
const char* T_GaMa_approx_Review_of_approximate_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_approx_computed_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_approx_given_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_approx_header1 = T_language_cpp_internal_error;
const char* T_GaMa_approx_observations = T_language_cpp_internal_error;
const char* T_GaMa_approx_separator = T_language_cpp_internal_error;
const char* T_GaMa_approx_total = T_language_cpp_internal_error;
const char* T_GaMa_detected_singular_variables = T_language_cpp_internal_error;
const char* T_GaMa_direction = T_language_cpp_internal_error;
const char* T_GaMa_distance = T_language_cpp_internal_error;
const char* T_GaMa_errell_header1 = T_language_cpp_internal_error;
const char* T_GaMa_errell_header2 = T_language_cpp_internal_error;
const char* T_GaMa_errell_review_of_mean_errors_and_error_ellipses = T_language_cpp_internal_error;
const char* T_GaMa_exception_1 = T_language_cpp_internal_error;
const char* T_GaMa_exception_2a = T_language_cpp_internal_error;
const char* T_GaMa_exception_2b = T_language_cpp_internal_error;
const char* T_GaMa_from_equals_to = T_language_cpp_internal_error;
const char* T_GaMa_genpar_Maximal_studentized_residual = T_language_cpp_internal_error;
const char* T_GaMa_genpar_critical_value = T_language_cpp_internal_error;
const char* T_GaMa_genpar_doesnt_exceed = T_language_cpp_internal_error;
const char* T_GaMa_genpar_exceeds = T_language_cpp_internal_error;
const char* T_GaMa_genpar_for_observation_ind = T_language_cpp_internal_error;
const char* T_GaMa_genpar_on_significance_level = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_adjusted_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_angles = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_computed_heights = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_computed_points = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_constrained_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_directions = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_distances = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_equations = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_fixed_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_fixed_heights = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_fixed_points = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_levelling_diffs = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_obs_total = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_observed_coords = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_points_total = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_redundancy = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_s_dists = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_total = T_language_cpp_internal_error;
const char* T_GaMa_gpar1_z_angles = T_language_cpp_internal_error;
const char* T_GaMa_gpar2_bearings = T_language_cpp_internal_error;
const char* T_GaMa_gpar2_constrained_heights = T_language_cpp_internal_error;
const char* T_GaMa_gpar2_constrained_points = T_language_cpp_internal_error;
const char* T_GaMa_gpar2_network_defect = T_language_cpp_internal_error;
const char* T_GaMa_gpar2_number_of_unknowns = T_language_cpp_internal_error;
const char* T_GaMa_inconsistent_coordinates_and_angles = T_language_cpp_internal_error;
const char* T_GaMa_index_type_point = T_language_cpp_internal_error;
const char* T_GaMa_internal_program_error = T_language_cpp_internal_error;
const char* T_GaMa_interval = T_language_cpp_internal_error;
const char* T_GaMa_interval_contains = T_language_cpp_internal_error;
const char* T_GaMa_interval_doesnt_contain = T_language_cpp_internal_error;
const char* T_GaMa_levell = T_language_cpp_internal_error;
const char* T_GaMa_m0_angles = T_language_cpp_internal_error;
const char* T_GaMa_m0_apriori = T_language_cpp_internal_error;
const char* T_GaMa_m0_directions = T_language_cpp_internal_error;
const char* T_GaMa_m0_dirs_angs = T_language_cpp_internal_error;
const char* T_GaMa_m0_distances = T_language_cpp_internal_error;
const char* T_GaMa_m0_empirical = T_language_cpp_internal_error;
const char* T_GaMa_missing_coordinates = T_language_cpp_internal_error;
const char* T_GaMa_network_description = T_language_cpp_internal_error;
const char* T_GaMa_not_enough_constrained_points = T_language_cpp_internal_error;
const char* T_GaMa_point = T_language_cpp_internal_error;
const char* T_GaMa_reduced_Review_of_reduced_observations = T_language_cpp_internal_error;
const char* T_GaMa_reduced_header1 = T_language_cpp_internal_error;
const char* T_GaMa_reduced_observed = T_language_cpp_internal_error;
const char* T_GaMa_reduced_reduced = T_language_cpp_internal_error;
const char* T_GaMa_reduced_value = T_language_cpp_internal_error;
const char* T_GaMa_resobs_Outlying_observations = T_language_cpp_internal_error;
const char* T_GaMa_resobs_Review_of_residuals_analysis_obs = T_language_cpp_internal_error;
const char* T_GaMa_resobs_condition_number = T_language_cpp_internal_error;
const char* T_GaMa_resobs_header1 = T_language_cpp_internal_error;
const char* T_GaMa_resobs_mc_critical = T_language_cpp_internal_error;
const char* T_GaMa_resobs_mc_max = T_language_cpp_internal_error;
const char* T_GaMa_resobs_mc_max_critical = T_language_cpp_internal_error;
const char* T_GaMa_resobs_no_control = T_language_cpp_internal_error;
const char* T_GaMa_resobs_normality_test = T_language_cpp_internal_error;
const char* T_GaMa_resobs_weak_control = T_language_cpp_internal_error;
const char* T_GaMa_s_distance = T_language_cpp_internal_error;
const char* T_GaMa_solution_ended_with_error = T_language_cpp_internal_error;
const char* T_GaMa_standpoint = T_language_cpp_internal_error;
const char* T_GaMa_statan_with_apriori_standard_deviation = T_language_cpp_internal_error;
const char* T_GaMa_statan_with_confidence_level = T_language_cpp_internal_error;
const char* T_GaMa_statan_with_empirical_standard_deviation = T_language_cpp_internal_error;
const char* T_GaMa_target = T_language_cpp_internal_error;
const char* T_GaMa_tstlin_Differences = T_language_cpp_internal_error;
const char* T_GaMa_tstlin_Test_of_linearization_error = T_language_cpp_internal_error;
const char* T_GaMa_tstlin_header1 = T_language_cpp_internal_error;
const char* T_GaMa_tstlin_header_value = T_language_cpp_internal_error;
const char* T_GaMa_tstlin_obs_r_diff = T_language_cpp_internal_error;
const char* T_GaMa_version = T_language_cpp_internal_error;
const char* T_GaMa_x = T_language_cpp_internal_error;
const char* T_GaMa_xdiff = T_language_cpp_internal_error;
const char* T_GaMa_y = T_language_cpp_internal_error;
const char* T_GaMa_ydiff = T_language_cpp_internal_error;
const char* T_GaMa_z = T_language_cpp_internal_error;
const char* T_GaMa_z_angle = T_language_cpp_internal_error;
const char* T_GaMa_zdiff = T_language_cpp_internal_error;
const char* T_IE_internal_error = T_language_cpp_internal_error;
const char* T_LN_rm_huge_cov_xy = T_language_cpp_internal_error;
const char* T_LN_rm_huge_cov_xyz = T_language_cpp_internal_error;
const char* T_LN_rm_huge_cov_z = T_language_cpp_internal_error;
const char* T_LN_rm_missing_xy = T_language_cpp_internal_error;
const char* T_LN_rm_missing_xyz = T_language_cpp_internal_error;
const char* T_LN_rm_missing_z = T_language_cpp_internal_error;
const char* T_LN_rm_removed_points = T_language_cpp_internal_error;
const char* T_LN_rm_singular_xy = T_language_cpp_internal_error;
const char* T_LN_undefined_confidence_level = T_language_cpp_internal_error;
const char* T_LN_undefined_type_of_actual_sigma = T_language_cpp_internal_error;
const char* T_POBS_bad_data = T_language_cpp_internal_error;
const char* T_POBS_computation_of_bearing_for_identical_points = T_language_cpp_internal_error;
const char* T_POBS_zero_or_negative_distance = T_language_cpp_internal_error;
const char* T_POBS_zero_or_negative_slope_distance = T_language_cpp_internal_error;
const char* T_POBS_zero_or_negative_zenith_angle = T_language_cpp_internal_error;

void set_gama_language(gama_language lang)
{
   switch(lang)
   {
   default:
   case en:
	T_GKF_bad_angle="bad angle: ";
	T_GKF_bad_attribute_angle_dev="bad attribute angle-stdev: ";
	T_GKF_bad_attribute_direction_dev="bad attribute direction-stdev: ";
	T_GKF_bad_attribute_distance_dev="bad attribute distance-stdev: ";
	T_GKF_bad_coordinate_x="bad coordinate x: ";
	T_GKF_bad_coordinate_y="bad coordinate y: ";
	T_GKF_bad_direction="bad direction: ";
	T_GKF_bad_distance="bad distance: ";
	T_GKF_bad_height="bad height: ";
	T_GKF_bad_height_diff="bad height difference: ";
	T_GKF_bad_instrument_reflector_height="bad instrument/reflector height: ";
	T_GKF_bad_network_configuration_unknown_parameter="bad network configuration - unknown parameter: ";
	T_GKF_bad_orientation_angle="bad orientation angle: ";
	T_GKF_bad_vector_data="bad vector data";
	T_GKF_bad_zangle="bad zenith angle: ";
	T_GKF_coordinate_x_is_not_defined="coordinate x is not defined";
	T_GKF_coordinate_y_is_not_defined="coordinate y is not defined";
	T_GKF_coordinates_without_covariance_matrix="coordinates without covariance matrix";
	T_GKF_cov_dim_differs_from_number_of_coordinates="covariance matrix dimension differs from the number of coordinates";
	T_GKF_cov_dim_differs_from_number_of_vectors="covariance matrix dimension differs from the number of vectors";
	T_GKF_cov_mat_bad_band_width="missing band-width of covariance matrix: ";
	T_GKF_cov_mat_bad_dim="bad dimension of covariance matrix: ";
	T_GKF_cov_mat_bad_dim_not_enough_elements="bad dimension of covariance matrix - not enough elements";
	T_GKF_cov_mat_bad_dim_too_many_elements="bad dimension of covariance matrix - too many elements";
	T_GKF_cov_mat_bad_element="bad covariance matrix element: ";
	T_GKF_cov_mat_missing_band_width="missing band-width of covariance matrix";
	T_GKF_cov_mat_missing_dim="missing dimension of covariance matrix";
	T_GKF_covariance_matrix_is_not_positive_definite="variance-covariance matrix is not positive definite";
	T_GKF_e01a_illegal_tag="illegal_tag <";
	T_GKF_e01b_after_tag="> after tag";
	T_GKF_error_on_reading_of_absolute_terms_tolerance="error on reading of tolerance for identification of outlying absolute terms";
	T_GKF_error_on_reading_of_confidence_probability="error on reading of confidence probability";
	T_GKF_error_on_reading_of_standard_deviation="error on reading of standard deviation";
	T_GKF_illegal_standard_deviation="illegal standard deviation";
	T_GKF_illegal_text="illegal text";
	T_GKF_illegal_value_of_gama_xml_version="illegal value of attribue 'version' of tag <gama-xml>: ";
	T_GKF_missing_forepoint_id="missing forepoint ID";
	T_GKF_missing_from_ID="missing point ID (attribute from=\"...\")";
	T_GKF_missing_left_forepoint_id="missing left forepoint ID";
	T_GKF_missing_observed_value="missing observed value";
	T_GKF_missing_point_ID="missing point ID";
	T_GKF_missing_right_forepoint_id="missing right forepoint ID";
	T_GKF_missing_standpoint_id="missing standpoint ID";
	T_GKF_missing_tag_network="missing tag <network>";
	T_GKF_missing_to_ID="missing point ID (attribute to=\"...\")";
	T_GKF_multiple_definition_of_xy_in_tag_point="multiple dexinition of coordinates xy in tag <point>";
	T_GKF_multiple_definition_of_z_in_tag_point="multiple definition of coordinate z in tag <point>";
	T_GKF_must_start_with_gama_xml="document must start with tag <gama-xml>";
	T_GKF_no_observations_after_cov_mat="observations can not come after covariance matrix";
	T_GKF_point_must_define_xy_andor_z_inside_tag_coordinates="tag <point /> must define coordinates xy and/or z inside tag <coordinates>";
	T_GKF_undefined_attribute_of_angle="undefined attribute of <angle>: ";
	T_GKF_undefined_attribute_of_coordinates="undefined attribute of <coordinates>: ";
	T_GKF_undefined_attribute_of_cov_mat="undefined attribute of <cov-mat>: ";
	T_GKF_undefined_attribute_of_direction="undefined attribute of <direction>: ";
	T_GKF_undefined_attribute_of_distance="undefined attribute of <distance>: ";
	T_GKF_undefined_attribute_of_gama_xml="undefined attribute of tag <gama-xml>: ";
	T_GKF_undefined_attribute_of_height_differences="undefined attribute of <height-differences>: ";
	T_GKF_undefined_attribute_of_obs="undefined attribute of <obs>: ";
	T_GKF_undefined_attribute_of_points="undefined attribute of <point>: ";
	T_GKF_undefined_attribute_of_points_observations="undefined attribute of <points-observations>: ";
	T_GKF_undefined_attribute_of_slopedist="undefined attribute of <s-distance>: ";
	T_GKF_undefined_attribute_of_vectors="undefined attribute of tag <vectors>: ";
	T_GKF_undefined_attribute_of_zangle="undefined attribute of <z-angle>: ";
	T_GKF_undefined_height_type="undefined height type: ";
	T_GKF_undefined_point_type="undefined point type: ";
	T_GKF_undefined_value_of_attribute="illegal value of the attribute: ";
	T_GKF_vectors_without_covariance_matrix="vectors without covariance matrix";
	T_GKF_wrong_type_of_standard_deviation="wrong type of standard deviation";
	T_GaMa_Adjustment_of_geodetic_network="Adjustment of local geodetic network";
	T_GaMa_Approximate_coordinates_replaced="Approximate coordinates of computed points replaced by adjusted";
	T_GaMa_During_statistical_analysis_we_work="During statistical analysis we work";
	T_GaMa_Free_network="Free network";
	T_GaMa_Free_network_defect_is="Free network defect is ";
	T_GaMa_General_solution_parameters="General parameters of the adjustment";
	T_GaMa_Given_network_configuration_can_not_be_adjusted="Given network configuration can not be adjusted";
	T_GaMa_Maximal_decrease_of_m0="Maximal decrease of m0\'\'/m0 on elimination of one observation: ";
	T_GaMa_Maximal_normalized_residual="Maximal normalized residual ";
	T_GaMa_No_network_points_defined="No network points defined";
	T_GaMa_No_observations_available="No observations available";
	T_GaMa_No_points_available="No points available";
	T_GaMa_No_unknowns_defined="No unknowns have been defined";
	T_GaMa_Observatios_with_outlying_absolute_terms_removed="Observations with outlying absolute terms removed";
	T_GaMa_Ratio_empirical_to_apriori="Ratio m0\' aposteriori / m0 apriori: ";
	T_GaMa_Review_of_fixed_points="Fixed points";
	T_GaMa_abstrm_Review_of_outlying_abs_terms="Outlying absolute terms in project equations";
	T_GaMa_abstrm_header1="           observed     absolute\n";
	T_GaMa_abstrm_header2="== value ===== term ==\n\n";
	T_GaMa_adjobs_Adjusted_observations="Adjusted observations";
	T_GaMa_adjobs_adjusted="adjusted";
	T_GaMa_adjobs_header1=" std.dev conf.i.\n";
	T_GaMa_adjobs_observed="observed";
	T_GaMa_adjobs_value="== value ";
	T_GaMa_adjunk_Review_of_unknowns_bearings="Adjusted orientation unknowns";
	T_GaMa_adjunk_Review_of_unknowns_coordidantes="Adjusted coordinates";
	T_GaMa_adjunk_Review_of_unknowns_heights="Adjusted heights";
	T_GaMa_adjunk_constrained="constrained";
	T_GaMa_adjunk_header1="    approximate  correction  adjusted    std.dev conf.i.\n";
	T_GaMa_adjunk_header2="====== value ====== [m] ====== value ========== [mm] ===\n\n";
	T_GaMa_adjunk_header3="   approximate  correction  adjusted   std.dev conf.i.\n";
	T_GaMa_adjunk_header4="==== value [g] ==== [g] === value [g] ======= [cc] ===\n\n";
	T_GaMa_adjunk_header5="     approximate  correction  adjusted    std.dev conf.i.\n";
	T_GaMa_adjunk_header6="======= value ====== [m] ====== value ========== [mm] ===\n\n";
	T_GaMa_adjunk_mean_position_error_average="Average mean position error is ";
	T_GaMa_adjunk_mean_position_error_maximal="Maximal mean position error is ";
	T_GaMa_adjunk_mean_position_error_on_point=" mm on point ";
	T_GaMa_adjustment_iteration=" - adjustment iteration";
	T_GaMa_angle=" angle ";
	T_GaMa_approx_Review_of_approximate_coordinates="Approximate coordinates";
	T_GaMa_approx_computed_coordinates="computed    : ";
	T_GaMa_approx_given_coordinates="given       : ";
	T_GaMa_approx_header1="coordinates   ";
	T_GaMa_approx_observations="observations: ";
	T_GaMa_approx_separator="---------------------------------------------";
	T_GaMa_approx_total="total       : ";
	T_GaMa_detected_singular_variables="The following unknowns have been detected as linearly dependent";
	T_GaMa_direction=" dir.  ";
	T_GaMa_distance=" dist. ";
	T_GaMa_errell_header1="    mp      mxy      mean error ellipse  conf.err. ellipse   g\n";
	T_GaMa_errell_header2="== [mm] == [mm] ==== a [mm] b  alpha[g] ==== a' [mm] b' ========";
	T_GaMa_errell_review_of_mean_errors_and_error_ellipses="Mean errors and parameters of error ellipses";
	T_GaMa_exception_1="Error during creation of InfoSit object";
	T_GaMa_exception_2a="GaMa - error on reading XML input configuration file!";
	T_GaMa_exception_2b="On line number ";
	T_GaMa_from_equals_to="station and target are identical";
	T_GaMa_genpar_Maximal_studentized_residual="Maximal studentized residual ";
	T_GaMa_genpar_critical_value=" critical value ";
	T_GaMa_genpar_doesnt_exceed=" does not exceed";
	T_GaMa_genpar_exceeds=" exceeds";
	T_GaMa_genpar_for_observation_ind=" % for observation #";
	T_GaMa_genpar_on_significance_level="on significance level ";
	T_GaMa_gpar1_adjusted_coordinates="Adjusted";
	T_GaMa_gpar1_angles="Number of angles";
	T_GaMa_gpar1_computed_heights="Number of computed heights";
	T_GaMa_gpar1_computed_points="Total of adjusted points";
	T_GaMa_gpar1_constrained_coordinates="Constrained  * ";
	T_GaMa_gpar1_coordinates="Coordinates";
	T_GaMa_gpar1_directions="Number of directions";
	T_GaMa_gpar1_distances="Number of distances";
	T_GaMa_gpar1_equations="Number of project equations";
	T_GaMa_gpar1_fixed_coordinates="Fixed";
	T_GaMa_gpar1_fixed_heights="Number of fixed heights";
	T_GaMa_gpar1_fixed_points="Number of fixed points";
	T_GaMa_gpar1_levelling_diffs="Levelling differences";
	T_GaMa_gpar1_obs_total="Total of observations";
	T_GaMa_gpar1_observed_coords="Coordinates";
	T_GaMa_gpar1_points_total="Total of points";
	T_GaMa_gpar1_redundancy="Degrees of freedom";
	T_GaMa_gpar1_s_dists="Slope distances";
	T_GaMa_gpar1_total="Total";
	T_GaMa_gpar1_z_angles="Zenith angles";
	T_GaMa_gpar2_bearings="Number of bearings";
	T_GaMa_gpar2_constrained_heights="Constrained heights";
	T_GaMa_gpar2_constrained_points="Constrained points";
	T_GaMa_gpar2_network_defect="Network defect";
	T_GaMa_gpar2_number_of_unknowns="Number of unknowns";
	T_GaMa_inconsistent_coordinates_and_angles="Inconsistent coordinates and angles: \nchanging internally sign of all Y coordinates";
	T_GaMa_index_type_point="  index type point";
	T_GaMa_internal_program_error="GaMa - internal program error!";
	T_GaMa_interval="interval";
	T_GaMa_interval_contains="contains value m0\'/m0";
	T_GaMa_interval_doesnt_contain="does not contain value m0\'/m0";
	T_GaMa_levell=" h dif ";
	T_GaMa_m0_angles="m0\'/m0 (angles): ";
	T_GaMa_m0_apriori="m0  apriori    ";
	T_GaMa_m0_directions="m0\'/m0 (directions): ";
	T_GaMa_m0_dirs_angs="m0\'/m0 (directions/angles): ";
	T_GaMa_m0_distances="m0\'/m0 (distances): ";
	T_GaMa_m0_empirical="m0\' aposteriori";
	T_GaMa_missing_coordinates="Missing coordinates";
	T_GaMa_network_description="Network description";
	T_GaMa_not_enough_constrained_points="Not enough constrained points defined";
	T_GaMa_point="point";
	T_GaMa_reduced_Review_of_reduced_observations="Reduced observations";
	T_GaMa_reduced_header1="  diff dh\n";
	T_GaMa_reduced_observed="observed";
	T_GaMa_reduced_reduced="reduced";
	T_GaMa_reduced_value="== value ";
	T_GaMa_resobs_Outlying_observations="Outlying observations";
	T_GaMa_resobs_Review_of_residuals_analysis_obs="Residuals and analysis of observations";
	T_GaMa_resobs_condition_number="Condition number        : ";
	T_GaMa_resobs_header1="        f[%]        v    |v'|     e-obs.  e-adj.\n";
	T_GaMa_resobs_mc_critical=" c ";
	T_GaMa_resobs_mc_max=" m ";
	T_GaMa_resobs_mc_max_critical=" mc";
	T_GaMa_resobs_no_control=" u";
	T_GaMa_resobs_normality_test="Test of normality of homogenised residuals";
	T_GaMa_resobs_weak_control=" w";
	T_GaMa_s_distance=" slope ";
	T_GaMa_solution_ended_with_error="GaMa - solution ended with error!";
	T_GaMa_standpoint="standpoint";
	T_GaMa_statan_with_apriori_standard_deviation="- with apriori standard deviation ";
	T_GaMa_statan_with_confidence_level="- with confidence level ";
	T_GaMa_statan_with_empirical_standard_deviation="- with aposteriori standard deviation ";
	T_GaMa_target="target";
	T_GaMa_tstlin_Differences="Diffs in adj. observations from residuals and from adjusted coordinates";
	T_GaMa_tstlin_Test_of_linearization_error="Test of linearization error";
	T_GaMa_tstlin_header1="====== value == [mm|cc] == [cc] == [mm] =\n\n";
	T_GaMa_tstlin_header_value="======= value ";
	T_GaMa_tstlin_obs_r_diff="      observed     r        difference";
	T_GaMa_version="version: ";
	T_GaMa_x=" x     ";
	T_GaMa_xdiff=" x dif ";
	T_GaMa_y=" y     ";
	T_GaMa_ydiff=" y dif ";
	T_GaMa_z=" z     ";
	T_GaMa_z_angle=" zenit ";
	T_GaMa_zdiff=" z dif ";
	T_IE_internal_error="internal error";
	T_LN_rm_huge_cov_xy="indeterminable coordinates xy";
	T_LN_rm_huge_cov_xyz="indeterminable coordinates xyz";
	T_LN_rm_huge_cov_z="indeterminable coordinate z";
	T_LN_rm_missing_xy="missing coordiantes xy";
	T_LN_rm_missing_xyz="missing coordiantes xyz";
	T_LN_rm_missing_z="missing coordiantes z";
	T_LN_rm_removed_points="Removed points and coordinates";
	T_LN_rm_singular_xy="singular coordiantes xy";
	T_LN_undefined_confidence_level="undefined confidence level";
	T_LN_undefined_type_of_actual_sigma="Type of actual sigma is not defined (apriori / aposteriori)";
	T_POBS_bad_data="bad data";
	T_POBS_computation_of_bearing_for_identical_points="Computation of bearing for identical points";
	T_POBS_zero_or_negative_distance="zero or negative distance";
	T_POBS_zero_or_negative_slope_distance="zero or negative slope distance";
	T_POBS_zero_or_negative_zenith_angle="zero or negative zenith angle";
	return;

   case cz:
	T_GKF_bad_angle="chybný úhel: ";
	T_GKF_bad_attribute_angle_dev="chybný atribut angle-stdev: ";
	T_GKF_bad_attribute_direction_dev="chybný atribut direction-stdev: ";
	T_GKF_bad_attribute_distance_dev="chybný atribut distance-stdev: ";
	T_GKF_bad_coordinate_x="chybná souřadnice x:";
	T_GKF_bad_coordinate_y="chybná souřadnice y:";
	T_GKF_bad_direction="chybný směr: ";
	T_GKF_bad_distance="chybná délka: ";
	T_GKF_bad_height="chybná výška: ";
	T_GKF_bad_height_diff="chybné převýšení: ";
	T_GKF_bad_instrument_reflector_height="chybná výška přístroje/záměry: ";
	T_GKF_bad_network_configuration_unknown_parameter="chybná konfigurace sítě - neznámý parametr: ";
	T_GKF_bad_orientation_angle="chybný orientační posun: ";
	T_GKF_bad_vector_data="chybný vektor";
	T_GKF_bad_zangle="chybná zenitová vzdálenost: ";
	T_GKF_coordinate_x_is_not_defined="není definována souřadnice x";
	T_GKF_coordinate_y_is_not_defined="není definována souřadnice y";
	T_GKF_coordinates_without_covariance_matrix="souřadnice bez kovarianční matice";
	T_GKF_cov_dim_differs_from_number_of_coordinates="dimenze kovarianční matice se neshoduje s počtem souřadnic";
	T_GKF_cov_dim_differs_from_number_of_vectors="dimenze kovarianční matice se neshoduje s počtem vektorů";
	T_GKF_cov_mat_bad_band_width="chybna šířka pásu kovarianční matice: ";
	T_GKF_cov_mat_bad_dim="chybná dimenze kovarianční matice: ";
	T_GKF_cov_mat_bad_dim_not_enough_elements="chybná dimenze kovarianční matice - nedostatečný počet prvků";
	T_GKF_cov_mat_bad_dim_too_many_elements="chybná dimenze kovarianční matice - příliš mnoho prvků";
	T_GKF_cov_mat_bad_element="chybny prvek kovarianční matice: ";
	T_GKF_cov_mat_missing_band_width="chybí šířka pásu kovarianční matice";
	T_GKF_cov_mat_missing_dim="chybí dimenze kovarianční matice";
	T_GKF_covariance_matrix_is_not_positive_definite="varianční-kovarianční matice není positivně definitní";
	T_GKF_e01a_illegal_tag="nepovolená značka <";
	T_GKF_e01b_after_tag="> za značkou";
	T_GKF_error_on_reading_of_absolute_terms_tolerance="chyba při čtení tolerance pro identifikaci vybočujících absolutních členů";
	T_GKF_error_on_reading_of_confidence_probability="chyba při čtení konfidenční pravděpodobnosti";
	T_GKF_error_on_reading_of_standard_deviation="chyba při čtení apriorní jednotkové střední chyby";
	T_GKF_illegal_standard_deviation="neplatná střední chyba";
	T_GKF_illegal_text="nepovolený text";
	T_GKF_illegal_value_of_gama_xml_version="nepovolená hodnota atributu 'version' znacky <gama-xml>: ";
	T_GKF_missing_forepoint_id="chybí číslo cíle";
	T_GKF_missing_from_ID="chybí číslo bodu (atribut from=\"...\")";
	T_GKF_missing_left_forepoint_id="chybí číslo cíle vlevo";
	T_GKF_missing_observed_value="chybí měřená hodnota";
	T_GKF_missing_point_ID="chybí číslo bodu";
	T_GKF_missing_right_forepoint_id="chybí číslo cíle vpravo";
	T_GKF_missing_standpoint_id="chybí číslo stanoviska";
	T_GKF_missing_tag_network="chybí značka <network>";
	T_GKF_missing_to_ID="chybí číslo bodu (atribut to=\"...\")";
	T_GKF_multiple_definition_of_xy_in_tag_point="vícenásobná definice souřadnic xy ve značce <point>";
	T_GKF_multiple_definition_of_z_in_tag_point="vícenásobná definice souřadnice z ve značce <point>";
	T_GKF_must_start_with_gama_xml="dávka musí začínat značkou <gama-xml>";
	T_GKF_no_observations_after_cov_mat="meření nesmí následovat za kovarianční maticí";
	T_GKF_point_must_define_xy_andor_z_inside_tag_coordinates="značka <point /> musí definovat souřadnice xy anebo z uvnitř značky <coordinates>";
	T_GKF_undefined_attribute_of_angle="nedefinovaný atribut značky <angle>: ";
	T_GKF_undefined_attribute_of_coordinates="nedefinovaný atribut značky <coordinates>: ";
	T_GKF_undefined_attribute_of_cov_mat="nedefinovaný atribut značky <cov-mat>: ";
	T_GKF_undefined_attribute_of_direction="nedefinovaný atribut značky <direction>: ";
	T_GKF_undefined_attribute_of_distance="nedefinovaný atribut značky <distance>: ";
	T_GKF_undefined_attribute_of_gama_xml="nedefinovaný atribut značky <gama-xml>: ";
	T_GKF_undefined_attribute_of_height_differences="nedefinovaný atribut značky <height-differences>: ";
	T_GKF_undefined_attribute_of_obs="nedefinovaný atribut značky <obs>: ";
	T_GKF_undefined_attribute_of_points="nedefinovaný atribut značky <point>: ";
	T_GKF_undefined_attribute_of_points_observations="nedefinovaný atribut značky <points-observations>: ";
	T_GKF_undefined_attribute_of_slopedist="nedefinovaný atribut značky <s-distance>: ";
	T_GKF_undefined_attribute_of_vectors="nedefinovaný atribut značky <vectors>: ";
	T_GKF_undefined_attribute_of_zangle="nedefinovaný atribut značky <z-angle>: ";
	T_GKF_undefined_height_type="nedefinovaný typ výšky: ";
	T_GKF_undefined_point_type="nedefinovaný typ bodu: ";
	T_GKF_undefined_value_of_attribute="nepovolená hodnota atributu: ";
	T_GKF_vectors_without_covariance_matrix="vektory bez kovarianční matice";
	T_GKF_wrong_type_of_standard_deviation="chybný typ empirické jednotkové střední chyby";
	T_GaMa_Adjustment_of_geodetic_network="Vyrovnání místní geodetické sítě";
	T_GaMa_Approximate_coordinates_replaced="Přibližné souřadnice určovaných bodů nahrazeny vyrovnanými";
	T_GaMa_During_statistical_analysis_we_work="Při statistické analýze se pracuje";
	T_GaMa_Free_network="Volná síť";
	T_GaMa_Free_network_defect_is="Defekt volné sítě je ";
	T_GaMa_General_solution_parameters="Základní parametry vyrovnání";
	T_GaMa_Given_network_configuration_can_not_be_adjusted="Zadanou konfiguraci sítě nelze vyrovnat";
	T_GaMa_Maximal_decrease_of_m0="Maximální pokles m0\'\'/m0 při vyloučení jednoho pozorování: ";
	T_GaMa_Maximal_normalized_residual="Maximální normovaná oprava ";
	T_GaMa_No_network_points_defined="Nebyly zadány žádné body sítě";
	T_GaMa_No_observations_available="Nebyla zadána žádná měření";
	T_GaMa_No_points_available="Nebyly zadány žádné body";
	T_GaMa_No_unknowns_defined="Nejsou definovány žádné neznámé";
	T_GaMa_Observatios_with_outlying_absolute_terms_removed="Měření s vybočujícími absolutními členy vyloučena";
	T_GaMa_Ratio_empirical_to_apriori="Poměr m0\' aposteriorní / m0 apriorní: ";
	T_GaMa_Review_of_fixed_points="Pevné body";
	T_GaMa_abstrm_Review_of_outlying_abs_terms="Vybočujících absolutních členů rovnic oprav";
	T_GaMa_abstrm_header1="             meřená    absolutní\n";
	T_GaMa_abstrm_header2=" hodnota ===== člen ==\n\n";
	T_GaMa_adjobs_Adjusted_observations="Vyrovnaná pozorování";
	T_GaMa_adjobs_adjusted="vyrovnaná";
	T_GaMa_adjobs_header1=" stř.ch. konf.i.\n";
	T_GaMa_adjobs_observed="měřená";
	T_GaMa_adjobs_value=" hodnota ";
	T_GaMa_adjunk_Review_of_unknowns_bearings="Vyrovnané orientační posuny";
	T_GaMa_adjunk_Review_of_unknowns_coordidantes="Vyrovnané souřadnice";
	T_GaMa_adjunk_Review_of_unknowns_heights="Vyrovnané výšky";
	T_GaMa_adjunk_constrained="opěrný";
	T_GaMa_adjunk_header1="     približná    korekce    vyrovnaná   stř.ch. konf.i.\n";
	T_GaMa_adjunk_header2="===== hodnota ===== [m] ===== hodnota ========= [mm] ===\n\n";
	T_GaMa_adjunk_header3="     priblizna    korekce   vyrovnana  stř.ch. konf.i.\n";
	T_GaMa_adjunk_header4="==== hodn. [g] ==== [g] === hodn. [g] ======= [cc] ===\n\n";
	T_GaMa_adjunk_header5="      přibližná    korekce    vyrovnaná   stř.ch. konf.i.\n";
	T_GaMa_adjunk_header6="====== hodnota ===== [m] ===== hodnota ========= [mm] ===\n\n";
	T_GaMa_adjunk_mean_position_error_average="Průměrná polohová chyba je ";
	T_GaMa_adjunk_mean_position_error_maximal="Maximální střední polohová chyba je ";
	T_GaMa_adjunk_mean_position_error_on_point=" mm na bodě ";
	T_GaMa_adjustment_iteration=". opakované vyrovnání";
	T_GaMa_angle=" úhel  ";
	T_GaMa_approx_Review_of_approximate_coordinates="Přibližné souřadnice";
	T_GaMa_approx_computed_coordinates="vypočtené   : ";
	T_GaMa_approx_given_coordinates="dané        : ";
	T_GaMa_approx_header1="souřadnice    ";
	T_GaMa_approx_observations="měření      : ";
	T_GaMa_approx_separator="---------------------------------------------";
	T_GaMa_approx_total="celkem      : ";
	T_GaMa_detected_singular_variables="Jako lineárně závislé byly určeny následující proměnné";
	T_GaMa_direction=" směr  ";
	T_GaMa_distance=" délka ";
	T_GaMa_errell_header1="    mp      mxy       stred. el. chyb     konfid. el. chyb   g\n";
	T_GaMa_errell_header2="== [mm] == [mm] ==== a [mm] b   alfa[g] ==== a' [mm] b' ========";
	T_GaMa_errell_review_of_mean_errors_and_error_ellipses="Střední chyby a parametry elips chyb";
	T_GaMa_exception_1="Chyba při vytváření objektu InfoSit";
	T_GaMa_exception_2a="GaMa - chyba při čtení XML konfiguračního souboru!";
	T_GaMa_exception_2b="Na řádku číslo ";
	T_GaMa_from_equals_to="stanovisko je totožné s cílem";
	T_GaMa_genpar_Maximal_studentized_residual="Maximální studentizovaná oprava ";
	T_GaMa_genpar_critical_value=" kritickou hodnotu ";
	T_GaMa_genpar_doesnt_exceed=" nepřesahuje";
	T_GaMa_genpar_exceeds=" přesahuje";
	T_GaMa_genpar_for_observation_ind=" % pro pozorování #";
	T_GaMa_genpar_on_significance_level="na hladině významnosti ";
	T_GaMa_gpar1_adjusted_coordinates="Vyrovnané";
	T_GaMa_gpar1_angles="Počet úhlů";
	T_GaMa_gpar1_computed_heights="Počet určovaných výšek";
	T_GaMa_gpar1_computed_points="Počet určovaných bodů";
	T_GaMa_gpar1_constrained_coordinates="Opěrné  * ";
	T_GaMa_gpar1_coordinates="Souřadnice";
	T_GaMa_gpar1_directions="Počet směrů";
	T_GaMa_gpar1_distances="Počet délek";
	T_GaMa_gpar1_equations="Počet rovnic oprav";
	T_GaMa_gpar1_fixed_coordinates="Pevné";
	T_GaMa_gpar1_fixed_heights="Počet daných výšek";
	T_GaMa_gpar1_fixed_points="Počet pevných bodů";
	T_GaMa_gpar1_levelling_diffs="Nivelační převýšení";
	T_GaMa_gpar1_obs_total="Celkem pozorování";
	T_GaMa_gpar1_observed_coords="Souřadnice";
	T_GaMa_gpar1_points_total="Bodů celkem";
	T_GaMa_gpar1_redundancy="Počet nadbyt. pozorování";
	T_GaMa_gpar1_s_dists="Šikmé délky";
	T_GaMa_gpar1_total="Celkem";
	T_GaMa_gpar1_z_angles="Zenitové úhly";
	T_GaMa_gpar2_bearings="Počet osnov";
	T_GaMa_gpar2_constrained_heights="Opěrné výšky";
	T_GaMa_gpar2_constrained_points="Opěrné body";
	T_GaMa_gpar2_network_defect="Defekt sítě";
	T_GaMa_gpar2_number_of_unknowns="Počet neznámých";
	T_GaMa_inconsistent_coordinates_and_angles="Nekonzistentní souřadnice a úhly: \ninterní změna znaménka všech souřadnic Y";
	T_GaMa_index_type_point="  index typ  bod";
	T_GaMa_internal_program_error="GaMa - interní chyba programu!";
	T_GaMa_interval="interval";
	T_GaMa_interval_contains="obsahuje hodnotu m0\'/m0";
	T_GaMa_interval_doesnt_contain="neobsahuje hodnotu m0\'/m0";
	T_GaMa_levell=" přev. ";
	T_GaMa_m0_angles="m0\'/m0 (úhly): ";
	T_GaMa_m0_apriori="m0  apriorní    ";
	T_GaMa_m0_directions="m0\'/m0 (směry): ";
	T_GaMa_m0_dirs_angs="m0\'/m0 (směry/úhly): ";
	T_GaMa_m0_distances="m0\'/m0 (délky): ";
	T_GaMa_m0_empirical="m0\' aposteriorní";
	T_GaMa_missing_coordinates="Chybějící souřadnice";
	T_GaMa_network_description="Popis sítě";
	T_GaMa_not_enough_constrained_points="Nebyl definován dostatečný počet opěrných bodů";
	T_GaMa_point="bod";
	T_GaMa_reduced_Review_of_reduced_observations="Redukovaná pozorování";
	T_GaMa_reduced_header1=" rozd. dh\n";
	T_GaMa_reduced_observed="měřená";
	T_GaMa_reduced_reduced="redukovaná";
	T_GaMa_reduced_value=" hodnota ";
	T_GaMa_resobs_Outlying_observations="Odlehlá pozorování";
	T_GaMa_resobs_Review_of_residuals_analysis_obs="Opravy a analýza pozorování";
	T_GaMa_resobs_condition_number="Číslo podmíněnosti      : ";
	T_GaMa_resobs_header1="        f[%]        v    |v'|     e-mer.  e-vyr.\n";
	T_GaMa_resobs_mc_critical=" k ";
	T_GaMa_resobs_mc_max=" m ";
	T_GaMa_resobs_mc_max_critical=" mk";
	T_GaMa_resobs_no_control=" n";
	T_GaMa_resobs_normality_test="Oveření normálního rozdělení homogenizovaných oprav";
	T_GaMa_resobs_weak_control=" s";
	T_GaMa_s_distance=" šikmá ";
	T_GaMa_solution_ended_with_error="GaMa - výpočet skončil chybou!";
	T_GaMa_standpoint="stanovisko";
	T_GaMa_statan_with_apriori_standard_deviation="- s apriorní jednotkovou střední chybou ";
	T_GaMa_statan_with_confidence_level="- s konfidenční pravděpodobností ";
	T_GaMa_statan_with_empirical_standard_deviation="- s aposteriorní jednotkovou střední chybou ";
	T_GaMa_target="cíl";
	T_GaMa_tstlin_Differences="Diference výpočtu vyrovnaných měření z oprav a z vyrovnaných souřadnic";
	T_GaMa_tstlin_Test_of_linearization_error="Test chyby z linearizace";
	T_GaMa_tstlin_header1="===== hodnota = [mm|cc] == [cc] == [mm] =\n\n";
	T_GaMa_tstlin_header_value="===== hodnota ";
	T_GaMa_tstlin_obs_r_diff="       merena      v         diference";
	T_GaMa_version="verze: ";
	T_GaMa_x=" x     ";
	T_GaMa_xdiff=" x dif ";
	T_GaMa_y=" y     ";
	T_GaMa_ydiff=" y dif ";
	T_GaMa_z=" z     ";
	T_GaMa_z_angle=" zenit ";
	T_GaMa_zdiff=" z dif ";
	T_IE_internal_error="interní chyba";
	T_LN_rm_huge_cov_xy="neurčitelné souřadnice xy";
	T_LN_rm_huge_cov_xyz="neurčitelné souřadnice xyz";
	T_LN_rm_huge_cov_z="neurčitelná souřadnice z";
	T_LN_rm_missing_xy="chybí souřadnice xy";
	T_LN_rm_missing_xyz="chybí souřadnice xyz";
	T_LN_rm_missing_z="chybí souřadnice z";
	T_LN_rm_removed_points="Vyloučené body a suřadnice";
	T_LN_rm_singular_xy="singulární souřadnice xy";
	T_LN_undefined_confidence_level="nedefinovaná hodnota pravděpodobnosti";
	T_LN_undefined_type_of_actual_sigma="Není definován typ aktuální jednotkové střední chyby (apriorní / aposteriorní)";
	T_POBS_bad_data="chybný údaj";
	T_POBS_computation_of_bearing_for_identical_points="Výpočet směrníku pro identické body";
	T_POBS_zero_or_negative_distance="nulová nebo záporná délka";
	T_POBS_zero_or_negative_slope_distance="nulová nebo záporná šikmá délka";
	T_POBS_zero_or_negative_zenith_angle="nulová nebo záporná zenitová vzdálenost";
	return;

   case fi:
	T_GKF_bad_angle="epäkelpo kulma: ";
	T_GKF_bad_attribute_angle_dev="virheellinen atribuutti angle-stdev: ";
	T_GKF_bad_attribute_direction_dev="virheellinen atribuuttu direction-stdev: ";
	T_GKF_bad_attribute_distance_dev="virheellinen atribuutti distance-sdev: ";
	T_GKF_bad_coordinate_x="epäkelpo x-koordinaatti: ";
	T_GKF_bad_coordinate_y="epäkelpo y-koordinaatti: ";
	T_GKF_bad_direction="epäkelpo suunta: ";
	T_GKF_bad_distance="epäkelpo etäisyys: ";
	T_GKF_bad_height="epäkelpo korkeus: ";
	T_GKF_bad_height_diff="epäkelpo korkeusero: ";
	T_GKF_bad_instrument_reflector_height="bad instrument/reflector height: ";
	T_GKF_bad_network_configuration_unknown_parameter="virheellinen verkkokonfiguraatio - tuntematon parametri; ";
	T_GKF_bad_orientation_angle="epäkelpo liitoskulma: ";
	T_GKF_bad_vector_data="epäkelpoa vektoridataa";
	T_GKF_bad_zangle="bad zenith angle: ";
	T_GKF_coordinate_x_is_not_defined="x-koordinaatti ei ole määritetty";
	T_GKF_coordinate_y_is_not_defined="y-koordinaatti ei ole määritetty";
	T_GKF_coordinates_without_covariance_matrix="koordinaatteja ilman kovarianssimatriisia";
	T_GKF_cov_dim_differs_from_number_of_coordinates="kovarianssimatriisin dimensio on eri kuin koordinaattien lukumäärä";
	T_GKF_cov_dim_differs_from_number_of_vectors="kovarianssimatriisin dimensio eroaa vektoreiden lukumäärästä";
	T_GKF_cov_mat_bad_band_width="puuttuva kovarianssimatriisin leveys: ";
	T_GKF_cov_mat_bad_dim="epäkelpo kovarianssimatriisin dimenssio: ";
	T_GKF_cov_mat_bad_dim_not_enough_elements="epäkelpo kovarianssimatriisin dimensio - ei tarpeeksi elementtejä";
	T_GKF_cov_mat_bad_dim_too_many_elements="epäkelpo kovarianssimatriisin dimensio - liian monta elementtiä";
	T_GKF_cov_mat_bad_element="epäkelpo kovarianssimatriisin elementti: ";
	T_GKF_cov_mat_missing_band_width="puuttuva kovarianssimatriisin leveys";
	T_GKF_cov_mat_missing_dim="puuttuva kovarianssimatriisin dimensio";
	T_GKF_covariance_matrix_is_not_positive_definite="varianssi-kovarianssimatriii ei ole positiivi definiitti";
	T_GKF_e01a_illegal_tag="sääntöjen vastainen tag <";
	T_GKF_e01b_after_tag="> tagin jälkeen";
	T_GKF_error_on_reading_of_absolute_terms_tolerance="virhe absoluuttisten termien karkeiden virheiden identtifioimistoleranssia luettaessa";
	T_GKF_error_on_reading_of_confidence_probability="virhe luottamustodennäköisyyttä luettaessa";
	T_GKF_error_on_reading_of_standard_deviation="virhe keskivirhettä luettaessa";
	T_GKF_illegal_standard_deviation="epäkelpo keskivirhe";
	T_GKF_illegal_text="virheellinen teksti";
	T_GKF_illegal_value_of_gama_xml_version="virheellinen arvo atribuutissa 'versio' tagissa <gama-xml>: ";
	T_GKF_missing_forepoint_id="puuttuva kohdepiste-ID";
	T_GKF_missing_from_ID="pisteen ID puuttuu (atribuutti from=\"...\")";
	T_GKF_missing_left_forepoint_id="puuttuva vasemman kohdepisteen ID";
	T_GKF_missing_observed_value="puuttuva havaittu arvo";
	T_GKF_missing_point_ID="pisteen ID puuttuu";
	T_GKF_missing_right_forepoint_id="puuttuva oikean kohdepisteen ID";
	T_GKF_missing_standpoint_id="puuttuva asemapiste-ID";
	T_GKF_missing_tag_network="tag <network> puuttuu;";
	T_GKF_missing_to_ID="pisteen ID puuttuu (atribuutti to=\"...\")";
	T_GKF_multiple_definition_of_xy_in_tag_point="xy-koordinaatit on määritetty useampaan kertaan tagissa <point>";
	T_GKF_multiple_definition_of_z_in_tag_point="z-koordinaatti on määritetty useampaan kertaan tagissa <point>";
	T_GKF_must_start_with_gama_xml="dokumentin pitää alkaa tagilla <gama-xml>";
	T_GKF_no_observations_after_cov_mat="havaintoja ei saa olla kovarianssimatriisin jälkeen";
	T_GKF_point_must_define_xy_andor_z_inside_tag_coordinates="tagin <point /> on määritettävä koordinaatit xy ja/tai z tagissa <coordinates>";
	T_GKF_undefined_attribute_of_angle="määrittämätön atribuutti <angle>: ";
	T_GKF_undefined_attribute_of_coordinates="määrittämätön atribuutti <coordinates>: ";
	T_GKF_undefined_attribute_of_cov_mat="määrittämätön atribuutti <cov-mat>: ";
	T_GKF_undefined_attribute_of_direction="määrittämätön atribuutti <direction>: ";
	T_GKF_undefined_attribute_of_distance="määrittämätön atribuutti <distance>: ";
	T_GKF_undefined_attribute_of_gama_xml="määrittelemätön atribuutti tagissa <gama-xml>: ";
	T_GKF_undefined_attribute_of_height_differences="määrittämätön atribuutti <height-differences>: ";
	T_GKF_undefined_attribute_of_obs="määrittämätön atribuutti <obs>: ";
	T_GKF_undefined_attribute_of_points="määrittelemätön atribuutti <point>: ";
	T_GKF_undefined_attribute_of_points_observations="määrittelmätön atribuutti <point-observations>: ";
	T_GKF_undefined_attribute_of_slopedist="määrittämätön atribuutti <s-distance>: ";
	T_GKF_undefined_attribute_of_vectors="määrittelemätön atribuutti tagissa <vectors>: ";
	T_GKF_undefined_attribute_of_zangle="määrittämätön atribuutti <z-angle>: ";
	T_GKF_undefined_height_type="määrittämätön korkeustyyppi: ";
	T_GKF_undefined_point_type="määrittämätön pistetyyppi: ";
	T_GKF_undefined_value_of_attribute="virheellinen atribuutin arvo: ";
	T_GKF_vectors_without_covariance_matrix="vektoreita ilman kovarianssimatriisia";
	T_GKF_wrong_type_of_standard_deviation="vääräntyyppinen keskivirhe";
	T_GaMa_Adjustment_of_geodetic_network="Paikallisen geodeettisen verkon tasoitus";
	T_GaMa_Approximate_coordinates_replaced="Laskettujen pisteiden likiarvoiset koordinaatit on korvattu tasoitetuilla";
	T_GaMa_During_statistical_analysis_we_work="Tilastollisessa analyysissä käytetään";
	T_GaMa_Free_network="Vapaa verkko";
	T_GaMa_Free_network_defect_is="Vapaa verkko on puutteellinen";
	T_GaMa_General_solution_parameters="Yleiset tasoitusparametrit";
	T_GaMa_Given_network_configuration_can_not_be_adjusted="Annettua verkkokonfiguraatiota ei ole mahdollista tasoittaa";
	T_GaMa_Maximal_decrease_of_m0="m0\'\'/m0 maksimaalinen pieneneminen yhtä havaintoa eliminoitaessa: ";
	T_GaMa_Maximal_normalized_residual="Normaalijakauman mukainen maksimiresiduaali";
	T_GaMa_No_network_points_defined="Verkkopisteitä ei ole määritelty";
	T_GaMa_No_observations_available="Havaintoja ei ole";
	T_GaMa_No_points_available="Pisteitä ei ole";
	T_GaMa_No_unknowns_defined="Tuntemattomia ei ole määritelty";
	T_GaMa_Observatios_with_outlying_absolute_terms_removed="Havaintoja, joiden absoluutisessa termissä on karkeita virheitä on poistettu";
	T_GaMa_Ratio_empirical_to_apriori="Suhdeluku m0\' aposteriori / m0 apriori: ";
	T_GaMa_Review_of_fixed_points="Kiintopisteet";
	T_GaMa_abstrm_Review_of_outlying_abs_terms="Karkeita virheitä projektiokaavoissa";
	T_GaMa_abstrm_header1="           havaittu absoluuttinen\n";
	T_GaMa_abstrm_header2="=== arvo ==== termi ==\n\n";
	T_GaMa_adjobs_Adjusted_observations="Tasoitetut havainnot";
	T_GaMa_adjobs_adjusted="tasoitettu";
	T_GaMa_adjobs_header1=" keskiv. luott.väli\n";
	T_GaMa_adjobs_observed="havaittu";
	T_GaMa_adjobs_value="== arvo  ";
	T_GaMa_adjunk_Review_of_unknowns_bearings="Tasoitetut orientaatiotuntemattomat";
	T_GaMa_adjunk_Review_of_unknowns_coordidantes="Tasoitetut koordinaatit";
	T_GaMa_adjunk_Review_of_unknowns_heights="Tasoitetut korkeudet";
	T_GaMa_adjunk_constrained="rajoitettu";
	T_GaMa_adjunk_header1="       liki       korjaus    tasoitettu kesk.haj. luott.väli.\n";
	T_GaMa_adjunk_header2="====== arvo ======= [m] ====== arvo =========== [mm] ===\n\n";
	T_GaMa_adjunk_header3="       liki     korjaus   tasoitettu   kesk.haj. luott.väli\n";
	T_GaMa_adjunk_header4="==== arvo  [g] ==== [g] === arvo  [g] ======= [cc] ===\n\n";
	T_GaMa_adjunk_header5="    likimääräinen  korjaus    tasoitettu  kesk.haj luott.väli\n";
	T_GaMa_adjunk_header6="======= arvo ======= [m] ====== arvo =========== [mm] ===\n\n";
	T_GaMa_adjunk_mean_position_error_average="Sijainnin keskimääräinen keskivirhe on ";
	T_GaMa_adjunk_mean_position_error_maximal="Sijainnin maksimikeskivirhe on ";
	T_GaMa_adjunk_mean_position_error_on_point=" mm pisteellä ";
	T_GaMa_adjustment_iteration=" - iteraatiokierros";
	T_GaMa_angle=" kulma ";
	T_GaMa_approx_Review_of_approximate_coordinates="Likimääräiset koordinaatit";
	T_GaMa_approx_computed_coordinates="laskettu    : ";
	T_GaMa_approx_given_coordinates="annettu     : ";
	T_GaMa_approx_header1="koordinaatit  ";
	T_GaMa_approx_observations="havainnot   : ";
	T_GaMa_approx_separator="---------------------------------------------";
	T_GaMa_approx_total="yhteensä    : ";
	T_GaMa_detected_singular_variables="Seuraavat tuntemattomat on havaittu lineaarisesti riippuvaisiksi";
	T_GaMa_direction=" suu.  ";
	T_GaMa_distance=" vaak. ";
	T_GaMa_errell_header1="    mp      mxy      virhe-ellipsi       luott. virhe-ell.   g\n";
	T_GaMa_errell_header2="== [mm] == [mm] ==== a [mm] b  alpha[g] ==== a' [mm] b' ========";
	T_GaMa_errell_review_of_mean_errors_and_error_ellipses="Keskivirheet ja virhe-ellipsien parametrit";
	T_GaMa_exception_1="Virhe InfoSit-objektia luotaessa";
	T_GaMa_exception_2a="GaMa - virhe XML-konfiguraatiotiedosotoa luettaessa!";
	T_GaMa_exception_2b="Rivillä numero ";
	T_GaMa_from_equals_to="havainto- ja kohdepiste ovat yhtäläiset";
	T_GaMa_genpar_Maximal_studentized_residual="Studentin t-jakauman mukainen maksimiresiduaali ";
	T_GaMa_genpar_critical_value=" kriittisen arvon ";
	T_GaMa_genpar_doesnt_exceed=" ei ylitä";
	T_GaMa_genpar_exceeds=" ylittää";
	T_GaMa_genpar_for_observation_ind=" % havainnolla #";
	T_GaMa_genpar_on_significance_level="merkitsevyystasolla ";
	T_GaMa_gpar1_adjusted_coordinates="Tasoitettu";
	T_GaMa_gpar1_angles="Kulmien lukumäärä";
	T_GaMa_gpar1_computed_heights="Laskettujen korkeuksien määrä";
	T_GaMa_gpar1_computed_points="Tasoitettujen pisteiden kokonaismäärä";
	T_GaMa_gpar1_constrained_coordinates="Rajoitettu * ";
	T_GaMa_gpar1_coordinates="Koordinaatit";
	T_GaMa_gpar1_directions="Suuntien lukumäärä";
	T_GaMa_gpar1_distances="Etäisyyksien lukumäärä";
	T_GaMa_gpar1_equations="Virheyhtäloiden lukumäärä";
	T_GaMa_gpar1_fixed_coordinates="Kiinnitetty";
	T_GaMa_gpar1_fixed_heights="Kiinnitettyjen korkeuksien lukumäärä";
	T_GaMa_gpar1_fixed_points="Kiinnitettyjen pisteiden lukumäärä";
	T_GaMa_gpar1_levelling_diffs="Vaaitut korkeuserot";
	T_GaMa_gpar1_obs_total="Havaintojen kokonaislukumäärä";
	T_GaMa_gpar1_observed_coords="Koordinaatit";
	T_GaMa_gpar1_points_total="Pisteitä yhteensä";
	T_GaMa_gpar1_redundancy="Vapausasteet";
	T_GaMa_gpar1_s_dists="Vinoetäisyydet";
	T_GaMa_gpar1_total="Kokonaismäärä";
	T_GaMa_gpar1_z_angles="Zeniittikulmat";
	T_GaMa_gpar2_bearings="Viuhkojen lukumäärä";
	T_GaMa_gpar2_constrained_heights="Rajoitettuja korkeuksia";
	T_GaMa_gpar2_constrained_points="Rajoitetut pisteet";
	T_GaMa_gpar2_network_defect="Verkko on puutteellinen";
	T_GaMa_gpar2_number_of_unknowns="Tuntemattomien lukumäärä";
	T_GaMa_inconsistent_coordinates_and_angles="Ristiriitaisia koordinaatteja ja kulmia: kaikkien Y-koordinaattien merkit vaihdetaan";
	T_GaMa_index_type_point="  indexityyppinen piste";
	T_GaMa_internal_program_error="GaMa - ohjelman sisäinen virhe!";
	T_GaMa_interval="luottamusväli";
	T_GaMa_interval_contains="sisältää arvon m0\'/m0";
	T_GaMa_interval_doesnt_contain="ei sisällä arvoa m0\'/m0";
	T_GaMa_levell=" h ero ";
	T_GaMa_m0_angles="m0\'/m0 (kulmat): ";
	T_GaMa_m0_apriori="m0  apriori    ";
	T_GaMa_m0_directions="m0\'/m0 (suunnat): ";
	T_GaMa_m0_dirs_angs="m0\'/m0 (suunnat/kulmat): ";
	T_GaMa_m0_distances="m0\'/m0 (etäisyydet): ";
	T_GaMa_m0_empirical="m0\' aposteriori";
	T_GaMa_missing_coordinates="Puuttuvia koordinaatteja";
	T_GaMa_network_description="verkon kuvaus";
	T_GaMa_not_enough_constrained_points="Rajoitettuja pisteitä ei ole määritetty tarpeeksi";
	T_GaMa_point="piste";
	T_GaMa_reduced_Review_of_reduced_observations="Reduced observations";
	T_GaMa_reduced_header1="  diff dh\n";
	T_GaMa_reduced_observed="observed";
	T_GaMa_reduced_reduced="reduced";
	T_GaMa_reduced_value="== value ";
	T_GaMa_resobs_Outlying_observations="Karkeat virheet";
	T_GaMa_resobs_Review_of_residuals_analysis_obs="Residuaalit ja havaintojen analyysi";
	T_GaMa_resobs_condition_number="Tila numero             : ";
	T_GaMa_resobs_header1="        f[%]        v    |v'|     e-hav.  e-tas.\n";
	T_GaMa_resobs_mc_critical=" k ";
	T_GaMa_resobs_mc_max=" m ";
	T_GaMa_resobs_mc_max_critical=" mk";
	T_GaMa_resobs_no_control=" e";
	T_GaMa_resobs_normality_test="Homogenisoitujen residuaalien normaalisuustesti";
	T_GaMa_resobs_weak_control=" h";
	T_GaMa_s_distance=" etäisyys ";
	T_GaMa_solution_ended_with_error="GaMa - ratkaisu päättyi virheeseen!";
	T_GaMa_standpoint="asemapiste";
	T_GaMa_statan_with_apriori_standard_deviation="- apriori keskihajontaa ";
	T_GaMa_statan_with_confidence_level="- luottamustasolla ";
	T_GaMa_statan_with_empirical_standard_deviation="- aposteriori keskihajontaa ";
	T_GaMa_target="kohde";
	T_GaMa_tstlin_Differences="Eroja tasoitetuissa havainnoissa residuaaleista ja tasoitetuista koordinaateista";
	T_GaMa_tstlin_Test_of_linearization_error="Linearisointivirheen testi";
	T_GaMa_tstlin_header1="====== arvo === [mm|cc] == [cc] == [mm] =\n\n";
	T_GaMa_tstlin_header_value="======= arvo  ";
	T_GaMa_tstlin_obs_r_diff="      havaittu     r        erotus";
	T_GaMa_version="versio: ";
	T_GaMa_x=" x     ";
	T_GaMa_xdiff=" x ero ";
	T_GaMa_y=" y     ";
	T_GaMa_ydiff=" y ero ";
	T_GaMa_z=" z     ";
	T_GaMa_z_angle=" zeniiti ";
	T_GaMa_zdiff=" z ero ";
	T_IE_internal_error="sisäinen virhe";
	T_LN_rm_huge_cov_xy="xy-koordinaatteja on mahdoton laskea";
	T_LN_rm_huge_cov_xyz="xyz-koordinaatteja on mahdoton laskea";
	T_LN_rm_huge_cov_z="z-koordinaatti on mahdoton laskea";
	T_LN_rm_missing_xy="xy-koordinaatteja puuttuu";
	T_LN_rm_missing_xyz="xyz-koordinaatteja puuttuu";
	T_LN_rm_missing_z="z-koordinaatteja puuttuu";
	T_LN_rm_removed_points="Poistettuja pisteitä ja koordinaatteja";
	T_LN_rm_singular_xy="singulaarisia xy-koordinaatteja";
	T_LN_undefined_confidence_level="määrittelemätön luottamusväli";
	T_LN_undefined_type_of_actual_sigma="Sigman tyyppi on määrittelemätön (apriori / aposteriori)";
	T_POBS_bad_data="epäkelpoa dataa";
	T_POBS_computation_of_bearing_for_identical_points="Suunnan laskenta identtisille pisteille";
	T_POBS_zero_or_negative_distance="etäisyys nolla tai negatiivinen";
	T_POBS_zero_or_negative_slope_distance="vinomatka nolla tai negatiivinen";
	T_POBS_zero_or_negative_zenith_angle="zeniittikulma nolla tai negatiivinen";
	return;

   case du:
	T_GKF_bad_angle="ongeldige hoek: ";
	T_GKF_bad_attribute_angle_dev="ongeldige parameter st.afw hoek: ";
	T_GKF_bad_attribute_direction_dev="ongeldige parameter st.afw richting: ";
	T_GKF_bad_attribute_distance_dev="ongeldige parameter st.afw afstand: ";
	T_GKF_bad_coordinate_x="ongeldige x coördinaat: ";
	T_GKF_bad_coordinate_y="ongeldige y coördinaat: ";
	T_GKF_bad_direction="ongeldige richting: ";
	T_GKF_bad_distance="ongeldige afstand: ";
	T_GKF_bad_height="ongeldige hoogte: ";
	T_GKF_bad_height_diff="ongeldig hoogteverschil: ";
	T_GKF_bad_instrument_reflector_height="ongeldige instrument/reflector hoogte: ";
	T_GKF_bad_network_configuration_unknown_parameter="ongeldige netwerk configuratie - onbekende parameter: ";
	T_GKF_bad_orientation_angle="ongeldige orientatiehoek: ";
	T_GKF_bad_vector_data="ongeldige vector data";
	T_GKF_bad_zangle="bad zenith angle: ";
	T_GKF_coordinate_x_is_not_defined="x coÖrdinaat is niet gedefinieerd";
	T_GKF_coordinate_y_is_not_defined="y coÖrdinaat is niet gedefinieerd";
	T_GKF_coordinates_without_covariance_matrix="coördinaten zonder covariantiematrix";
	T_GKF_cov_dim_differs_from_number_of_coordinates="dimensie van de covariantiematrix verschilt van het aantal coördinaten";
	T_GKF_cov_dim_differs_from_number_of_vectors="dimensie van de covariantiematrix verschilt van het aantal vectoren";
	T_GKF_cov_mat_bad_band_width="band-breedte van covariantiematrix ontbreekt: ";
	T_GKF_cov_mat_bad_dim="ongeldige dimensie van covariantiematrix: ";
	T_GKF_cov_mat_bad_dim_not_enough_elements="ongeldige dimensie van covariance matrix - niet genoeg elementen";
	T_GKF_cov_mat_bad_dim_too_many_elements="ongeldige dimensie van covariance matrix - te veel elementen";
	T_GKF_cov_mat_bad_element="ongeldig covariantiematrix element: ";
	T_GKF_cov_mat_missing_band_width="band-breedte van covariantiematrix ontbreekt";
	T_GKF_cov_mat_missing_dim="dimensie van covariantiematrix ontbreekt";
	T_GKF_covariance_matrix_is_not_positive_definite="variante covariantiematrix is niet positief gedefinieerd";
	T_GKF_e01a_illegal_tag="ongeldige tag <";
	T_GKF_e01b_after_tag="> na tag";
	T_GKF_error_on_reading_of_absolute_terms_tolerance="fout bij lezen van tolerantie voor identificatie van absolute termen";
	T_GKF_error_on_reading_of_confidence_probability="fout bij lezen van betrouwbaarheidsfactor";
	T_GKF_error_on_reading_of_standard_deviation="fout bij lezen van standaardafwijking";
	T_GKF_illegal_standard_deviation="foutief type standaardafwijking";
	T_GKF_illegal_text="ongeldige tekst";
	T_GKF_illegal_value_of_gama_xml_version="ongeldige waarde van parameter 'versie' bij tag <gama-xml>: ";
	T_GKF_missing_forepoint_id="ontbrekende puntnummer";
	T_GKF_missing_from_ID="ontbrekende puntnummer (attribuut van=\"...\")";
	T_GKF_missing_left_forepoint_id="ontbrekende linkerpuntnummer";
	T_GKF_missing_observed_value="ontbrekende geobserveerde waarde";
	T_GKF_missing_point_ID="ontbrekende puntnummer";
	T_GKF_missing_right_forepoint_id="ontbrekende rechterpuntnummer";
	T_GKF_missing_standpoint_id="ontbrekend standpuntnummer";
	T_GKF_missing_tag_network="ontbrekende tag <network>";
	T_GKF_missing_to_ID="ontbrekende puntnummer (attribuut naar=\"...\")";
	T_GKF_multiple_definition_of_xy_in_tag_point="meerdere definities van xy coördinaten in tag <point>";
	T_GKF_multiple_definition_of_z_in_tag_point="meerdere definities van z coördinaten in <point>";
	T_GKF_must_start_with_gama_xml="document moet starten met tag <gama-xml>";
	T_GKF_no_observations_after_cov_mat="observaties kunnen niet na covariantiematrix gegeven worden";
	T_GKF_point_must_define_xy_andor_z_inside_tag_coordinates="tag <point /> moet xy coördinaten krijgen en/of z coördinaat bij tag <coordinates>";
	T_GKF_undefined_attribute_of_angle="geen attributen gedefinieerd voor tag <angle>: ";
	T_GKF_undefined_attribute_of_coordinates="geen attributen gedefinieerd voor <coordinates>: ";
	T_GKF_undefined_attribute_of_cov_mat="geen attributen gedefinieerd voor <cov-mat>: ";
	T_GKF_undefined_attribute_of_direction="geen attributen gedefinieerd voor <direction>: ";
	T_GKF_undefined_attribute_of_distance="geen attributen gedefinieerd voor <distance>: ";
	T_GKF_undefined_attribute_of_gama_xml="geen attributen gedefinieerd voor <gama-xml>: ";
	T_GKF_undefined_attribute_of_height_differences="geen attributen gedefinieerd voor <height-differences>: ";
	T_GKF_undefined_attribute_of_obs="geen attributen gedefinieerd voor <obs>: ";
	T_GKF_undefined_attribute_of_points="geen attributen gedefinieerd voor <point>: ";
	T_GKF_undefined_attribute_of_points_observations="geen attributen gedefinieerd voor <points-observations>: ";
	T_GKF_undefined_attribute_of_slopedist="geen attributen gedefinieerd voor <s-distance>: ";
	T_GKF_undefined_attribute_of_vectors="geen attributen gedefinieerd voor <vectors>: ";
	T_GKF_undefined_attribute_of_zangle="geen attributen gedefinieerd voor <z-angle>: ";
	T_GKF_undefined_height_type="hoogte type niet gedefinieerd: ";
	T_GKF_undefined_point_type="punt type niet gedefinieerd: ";
	T_GKF_undefined_value_of_attribute="ongeldige attribuut waarde: ";
	T_GKF_vectors_without_covariance_matrix="vectoren zonder covariantiematrix";
	T_GKF_wrong_type_of_standard_deviation="ongeldig type standaardafwijking";
	T_GaMa_Adjustment_of_geodetic_network="Vereffening van lokaal geodetisch netwerk";
	T_GaMa_Approximate_coordinates_replaced="Benaderende coördinaten van berekende punten vervangen door vereffende";
	T_GaMa_During_statistical_analysis_we_work="Tijdens statistische analyse werken we";
	T_GaMa_Free_network="Vrij netwerk";
	T_GaMa_Free_network_defect_is="Vrij netwerk defect is ";
	T_GaMa_General_solution_parameters="Algemene parameters van de vereffening";
	T_GaMa_Given_network_configuration_can_not_be_adjusted="Netwerk configuratie kan niet berekend worden";
	T_GaMa_Maximal_decrease_of_m0="Maximale vermindering van m0\'\'/m0 bij eliminatie van een observatie: ";
	T_GaMa_Maximal_normalized_residual="Maximale genormaliseerde residu ";
	T_GaMa_No_network_points_defined="Geen netwerkpunten gedefinieerd";
	T_GaMa_No_observations_available="Geen observaties beschikbaar";
	T_GaMa_No_points_available="Geen punten beschikbaar";
	T_GaMa_No_unknowns_defined="Er zijn geen onbekenden gedefinieerd";
	T_GaMa_Observatios_with_outlying_absolute_terms_removed="Verworpen observaties met afwijkende absolute condities";
	T_GaMa_Ratio_empirical_to_apriori="Ratio m0\' a posteriori / m0 a priori: ";
	T_GaMa_Review_of_fixed_points="Vaste punten";
	T_GaMa_abstrm_Review_of_outlying_abs_terms="Afwijkende absolute condities in project vergelijkingen";
	T_GaMa_abstrm_header1="           Geobserveerd     Absolute\n";
	T_GaMa_abstrm_header2="== waarde ===== cond ==\n\n";
	T_GaMa_adjobs_Adjusted_observations="Vereffende observaties";
	T_GaMa_adjobs_adjusted="vereffend";
	T_GaMa_adjobs_header1=" std.afw betr.i.\n";
	T_GaMa_adjobs_observed="geobserveerd";
	T_GaMa_adjobs_value="== waarde ";
	T_GaMa_adjunk_Review_of_unknowns_bearings="Vereffende orientatie onbekenden";
	T_GaMa_adjunk_Review_of_unknowns_coordidantes="Vereffende coördinaten";
	T_GaMa_adjunk_Review_of_unknowns_heights="Vereffende hoogtes";
	T_GaMa_adjunk_constrained="constrained";
	T_GaMa_adjunk_header1="   benaderende   correctie  vereffende std.afw betr.i.\n";
	T_GaMa_adjunk_header2="==== waarde ====== [m] ====== waarde ======== [mm] ===\n\n";
	T_GaMa_adjunk_header3="   benaderende   correctie  vereffende std.afw betr.i.\n";
	T_GaMa_adjunk_header4="==== waarde[g] ==== [g] === value [g] ======= [cc] ===\n\n";
	T_GaMa_adjunk_header5="   benaderende   correctie  vereffende std.afw betr.i.\n";
	T_GaMa_adjunk_header6="===== waarde ====== [m] ====== waarde======== [mm] ===\n\n";
	T_GaMa_adjunk_mean_position_error_average="Gemmiddelde afwijking ";
	T_GaMa_adjunk_mean_position_error_maximal="Maximale afwijking ";
	T_GaMa_adjunk_mean_position_error_on_point=" mm op punt ";
	T_GaMa_adjustment_iteration=" - iteraties";
	T_GaMa_angle=" hoek ";
	T_GaMa_approx_Review_of_approximate_coordinates="Benaderende coördinaten";
	T_GaMa_approx_computed_coordinates="berekende    : ";
	T_GaMa_approx_given_coordinates="gegeven       : ";
	T_GaMa_approx_header1="coördinaten   ";
	T_GaMa_approx_observations="observaties: ";
	T_GaMa_approx_separator="---------------------------------------------";
	T_GaMa_approx_total="totaal       : ";
	T_GaMa_detected_singular_variables="De volgende onbekenden zijn gedetecteerd als lineair afhankelijk";
	T_GaMa_direction=" richting  ";
	T_GaMa_distance=" afstand ";
	T_GaMa_errell_header1="    mp      mxy      alg. fout ellips  conf.err. ellips   g\n";
	T_GaMa_errell_header2="== [mm] == [mm] ==== a [mm] b  alpha[g] ==== a' [mm] b' ========";
	T_GaMa_errell_review_of_mean_errors_and_error_ellipses="Algemene fouten en parameters van de standaard ellipsen";
	T_GaMa_exception_1="Fout tijdens creëren van InfoSit object";
	T_GaMa_exception_2a="Fout bij lezen van XML input configuratie bestand!";
	T_GaMa_exception_2b="Op lijn nummer ";
	T_GaMa_from_equals_to="standpunt en richtpunt zijn identiek";
	T_GaMa_genpar_Maximal_studentized_residual="Maximale residu ";
	T_GaMa_genpar_critical_value=" kritieke waarde ";
	T_GaMa_genpar_doesnt_exceed=" overschrijdt niet";
	T_GaMa_genpar_exceeds=" overschrijdt";
	T_GaMa_genpar_for_observation_ind=" % voor observatie #";
	T_GaMa_genpar_on_significance_level="on niveau ";
	T_GaMa_gpar1_adjusted_coordinates="Vereffend";
	T_GaMa_gpar1_angles="Aantal hoeken";
	T_GaMa_gpar1_computed_heights="Aantal berekende hoogtes";
	T_GaMa_gpar1_computed_points="Totaal aantal vereffende punten";
	T_GaMa_gpar1_constrained_coordinates="Constrained  * ";
	T_GaMa_gpar1_coordinates="Coördinaten";
	T_GaMa_gpar1_directions="Aantal richtingen";
	T_GaMa_gpar1_distances="Aantal afstanden";
	T_GaMa_gpar1_equations="Aantal vergelijkingen";
	T_GaMa_gpar1_fixed_coordinates="Vast";
	T_GaMa_gpar1_fixed_heights="Aantal vaste hoogtes";
	T_GaMa_gpar1_fixed_points="Aantal vaste punten";
	T_GaMa_gpar1_levelling_diffs="Hoogte verschillen";
	T_GaMa_gpar1_obs_total="Totaal aantal observaties";
	T_GaMa_gpar1_observed_coords="Coördinaten";
	T_GaMa_gpar1_points_total="Totaal aantal punten";
	T_GaMa_gpar1_redundancy="Vrijheidsgraden";
	T_GaMa_gpar1_s_dists="Schuine afstand";
	T_GaMa_gpar1_total="Totaal";
	T_GaMa_gpar1_z_angles="Zenit hoeken";
	T_GaMa_gpar2_bearings="Aantal kaarthoeken";
	T_GaMa_gpar2_constrained_heights="Constrained hoogtes";
	T_GaMa_gpar2_constrained_points="Constrained punten";
	T_GaMa_gpar2_network_defect="Defect netwerk";
	T_GaMa_gpar2_number_of_unknowns="Aantal onbekenden";
	T_GaMa_inconsistent_coordinates_and_angles="Inconsistente coördinaten en hoeken: \nwijziging teken van alle XY coördinaten";
	T_GaMa_index_type_point="  index type punt";
	T_GaMa_internal_program_error="GaMa - interne programmafout!";
	T_GaMa_interval="interval";
	T_GaMa_interval_contains="bevat m0\'/m0 waarde ";
	T_GaMa_interval_doesnt_contain="bevat de  m0\'/m0 waarde niet";
	T_GaMa_levell=" h verschil ";
	T_GaMa_m0_angles="m0\'/m0 (hoeken): ";
	T_GaMa_m0_apriori="m0  apriori    ";
	T_GaMa_m0_directions="m0\'/m0 (richtingen): ";
	T_GaMa_m0_dirs_angs="m0\'/m0 (richtingen/hoeken): ";
	T_GaMa_m0_distances="m0\'/m0 (afstanden): ";
	T_GaMa_m0_empirical="m0\' a posteriori";
	T_GaMa_missing_coordinates="Ontbrekende coördinaten";
	T_GaMa_network_description="Netwerk omschrijving";
	T_GaMa_not_enough_constrained_points="Onvoldoende constrained punten gedefinieerd";
	T_GaMa_point="punt";
	T_GaMa_reduced_Review_of_reduced_observations="Reduced observations";
	T_GaMa_reduced_header1="  diff dh\n";
	T_GaMa_reduced_observed="observed";
	T_GaMa_reduced_reduced="reduced";
	T_GaMa_reduced_value="== value ";
	T_GaMa_resobs_Outlying_observations="Outlying observatie";
	T_GaMa_resobs_Review_of_residuals_analysis_obs="Residus en analyse van de observaties";
	T_GaMa_resobs_condition_number="Conditie nummer        : ";
	T_GaMa_resobs_header1="        f[%]        v    |v'|     e-obs.  e-ver.\n";
	T_GaMa_resobs_mc_critical=" c ";
	T_GaMa_resobs_mc_max=" m ";
	T_GaMa_resobs_mc_max_critical=" mc";
	T_GaMa_resobs_no_control=" u";
	T_GaMa_resobs_normality_test="Test van de homogene residus";
	T_GaMa_resobs_weak_control=" w";
	T_GaMa_s_distance=" slope ";
	T_GaMa_solution_ended_with_error="GaMa - oplossing beëindigd met fouten!";
	T_GaMa_standpoint="standpunt";
	T_GaMa_statan_with_apriori_standard_deviation="- met a priori standaardafwijking ";
	T_GaMa_statan_with_confidence_level="- met betrouwbaarheidsniveau ";
	T_GaMa_statan_with_empirical_standard_deviation="- met a posteriori standaardafwijking ";
	T_GaMa_target="richtpunt";
	T_GaMa_tstlin_Differences="Verschillen in ver. observaties van residus en vereffende coördinaten";
	T_GaMa_tstlin_Test_of_linearization_error="Test van de linearisatie fout";
	T_GaMa_tstlin_header1="====== waarde == [mm|cc] == [cc] == [mm] =\n\n";
	T_GaMa_tstlin_header_value="======= waarde ";
	T_GaMa_tstlin_obs_r_diff="      observatie     r        verschil";
	T_GaMa_version="versie: ";
	T_GaMa_x=" x     ";
	T_GaMa_xdiff=" x res ";
	T_GaMa_y=" y     ";
	T_GaMa_ydiff=" y res ";
	T_GaMa_z=" z     ";
	T_GaMa_z_angle=" zenit ";
	T_GaMa_zdiff=" z res ";
	T_IE_internal_error="interne fout";
	T_LN_rm_huge_cov_xy="onbepaalbare xy coördinaten";
	T_LN_rm_huge_cov_xyz="onbepaalbare xyz coördinaten";
	T_LN_rm_huge_cov_z="onbepaalbare z coördinaat";
	T_LN_rm_missing_xy="ontbrekende xy coördinaten";
	T_LN_rm_missing_xyz="ontbrekende xyz coördinaten";
	T_LN_rm_missing_z="ontbrekende z coördinaat";
	T_LN_rm_removed_points="Verworpen punten en coördinaten";
	T_LN_rm_singular_xy="singulaire xy coördinaten";
	T_LN_undefined_confidence_level="onbepaald betrouwbaarheidsniveau";
	T_LN_undefined_type_of_actual_sigma="Type sigma is niet gedefinieerd (a priori / a posteriori)";
	T_POBS_bad_data="foutieve data";
	T_POBS_computation_of_bearing_for_identical_points="Berekening van de kaarthoek voor identieke punten";
	T_POBS_zero_or_negative_distance="nul of negatieve afstand";
	T_POBS_zero_or_negative_slope_distance="nul of negatieve schuine afstand";
	T_POBS_zero_or_negative_zenith_angle="nul of negatieve zenit hoek";
	return;

   }

}

}   // namespace GaMaLib

